@@ -82,7 +82,7 @@ EXTERN_VAR BOOLEAN siCntrlc;
 #define OPT_RETURN_SB      9
 #define OPT_FASTHC        10
 #define OPT_OLDSTD        20
-
+#define OPT_REDTAIL_SYZ   21
 #define OPT_STAIRCASEBOUND 22
 #define OPT_MULTBOUND     23
 #define OPT_DEGBOUND      24
@@ -112,6 +112,7 @@ EXTERN_VAR BOOLEAN siCntrlc;
 #define TEST_OPT_MULTBOUND         BTEST1(OPT_MULTBOUND)
 #define TEST_OPT_STAIRCASEBOUND    BTEST1(OPT_STAIRCASEBOUND)
 #define TEST_OPT_REDTAIL           BTEST1(OPT_REDTAIL)
+#define TEST_OPT_REDTAIL_SYZ       BTEST1(OPT_REDTAIL_SYZ)
 #define TEST_OPT_INFREDTAIL        BTEST1(OPT_INFREDTAIL)
 #define TEST_OPT_SB_1              BTEST1(OPT_SB_1)
 #define TEST_OPT_NOTREGULARITY     BTEST1(OPT_NOTREGULARITY)
